@@ -51,7 +51,9 @@ For a more detailed explanation refer to the documentation.
 
 import inspect
 import sys
-import six
+
+is_PY2 = sys.version_info[0] == 2
+is_PY3 = sys.version_info[0] == 3
 
 #exported functions
 
@@ -487,13 +489,15 @@ def _funcspec(fn):
     Note that this is not a "full" functional specification, as we are only interested in certain parts.
     """
 
-    if six.PY2:
+    if is_PY2:
         fnargs, fnvarargname, fnkwname, fndefaults = inspect.getargspec(fn)
         fnkwonlyargs = []
         fnkwonlydefaults = None
         fnannotations = {}
-    elif six.PY3:
+    elif is_PY3:
         fnargs, fnvarargname, fnkwname, fndefaults, fnkwonlyargs, fnkwonlydefaults, fnannotations = inspect.getfullargspec(fn)
+    else:
+        return [], [], [], [], []
 
     # normalize to empty types instead of None
     fndefaults = fndefaults or []
